#
# spec file for package azure-li-services
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:             azure-li-services
Version:          1.2.8
Release:          1.23.1
Url:              https://github.com/SUSE/azure-li-services
Summary:          Azure Large Instance Services
License:          GPL-3.0+
Group:            System/Management
Source:           azure-li-services.tar.gz
BuildRoot:        %{_tmppath}/%{name}-%{version}-build
BuildRequires:    python3-devel
BuildRequires:    python3-setuptools
BuildRequires:    systemd-rpm-macros
Requires:         python3-PyYAML
Requires:         python3-setuptools
Requires:         python3-psutil
Requires:         python3-humanfriendly
Requires:         python3-Cerberus
Requires:         shadow
Requires(preun):  systemd
Requires(postun): systemd
%if 0%{?suse_version} > 1320
Requires:         createrepo-implementation
%else
Requires:         createrepo
%endif
Requires:         zypper
Requires:         rsync
BuildArch:        noarch

%description
Systemd services reading and processing the sections of a
configuration file provided to the system during the startup
phase of an Azure Large or Very Large Instance.

%prep
%setup -q -n azure_li_services-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

install -D -m 644 systemd/azure-li-config-lookup.service \
    %{buildroot}%{_unitdir}/azure-li-config-lookup.service

install -D -m 644 systemd/azure-li-network.service \
    %{buildroot}%{_unitdir}/azure-li-network.service

install -D -m 644 systemd/azure-li-user.service \
    %{buildroot}%{_unitdir}/azure-li-user.service

install -D -m 644 systemd/azure-li-call.service \
    %{buildroot}%{_unitdir}/azure-li-call.service

install -D -m 644 systemd/azure-li-install.service \
    %{buildroot}%{_unitdir}/azure-li-install.service

install -D -m 644 systemd/azure-li-report.service \
    %{buildroot}%{_unitdir}/azure-li-report.service

install -D -m 644 systemd/azure-li-cleanup.service \
    %{buildroot}%{_unitdir}/azure-li-cleanup.service

install -D -m 644 systemd/azure-li-machine-constraints.service \
    %{buildroot}%{_unitdir}/azure-li-machine-constraints.service

install -D -m 644 systemd/azure-li-storage.service \
    %{buildroot}%{_unitdir}/azure-li-storage.service

install -D -m 644 systemd/azure-li-system-setup.service \
    %{buildroot}%{_unitdir}/azure-li-system-setup.service

# preun / postun
# While the package provides services all services are one-shot.
# Additionally upon initial run, i.e. on first boot the package
# itself gets removed via the azure-li-cleanup implementation.
# This means there is no package update path as the package will
# be gone after initial boot. Therefore there is no need for
# use of the "standard" systemd service handling macros.

%files
%defattr(-,root,root,-)
%{python3_sitelib}/*

%{_bindir}/azure-li-config-lookup
%{_unitdir}/azure-li-config-lookup.service

%{_bindir}/azure-li-network
%{_unitdir}/azure-li-network.service

%{_bindir}/azure-li-user
%{_unitdir}/azure-li-user.service

%{_bindir}/azure-li-call
%{_unitdir}/azure-li-call.service

%{_bindir}/azure-li-install
%{_unitdir}/azure-li-install.service

%{_bindir}/azure-li-report
%{_unitdir}/azure-li-report.service

%{_bindir}/azure-li-cleanup
%{_unitdir}/azure-li-cleanup.service

%{_bindir}/azure-li-machine-constraints
%{_unitdir}/azure-li-machine-constraints.service

%{_bindir}/azure-li-storage
%{_unitdir}/azure-li-storage.service

%{_bindir}/azure-li-system-setup
%{_unitdir}/azure-li-system-setup.service

%changelog
* Fri Jul 24 2020 ms@suse.de
- Bump version: 1.2.7 → 1.2.8
* Thu Jul 23 2020 keith.berger@suse.com
- Fix motd SP version for SLE15 SP2 images
  The SLE15 SP2 images still have the version listed in the motd
  file as SLE15 SP1. This patch updates the motd to match the installed
  SLE15 SP2 version
* Mon Jul 20 2020 keith.berger@suse.com
- Fix printk timing issue
  This change adds 'loglevel=3' to the kernel command line.
  This is needed as a workaround to handing console messages
  as a kthread. In certain cases there colud be a process block
  while printing console messages. One viable worksround is to
  adjust the loglevel to '3' to only show messages for "error,
  critical, alert, and emergency."
* Wed Jul  1 2020 ms@suse.de
- Bump version: 1.2.6 → 1.2.7
* Fri Jun 26 2020 ms@suse.de
- Update prometheus monitoring modules
  As requested by jsc#SLE-10545, jsc#SLE-10902, jsc#SLE-10903,
  jsc#ECO-817 and jsc#ECO-818. This commit update/adds the additional
  monitoring modules for the LI and VLI images for SLE15-SP1/SP2
  and GA
* Fri Jun 26 2020 ms@suse.de
- Move to rsyslog for SLE12 VLI images
  rsyslog is requested over syslog-ng for the VLI images
  in SLE12. This Fixes #228
* Mon Jun 22 2020 ms@suse.de
- Added prometheus monitoring modules for SLE12
  As requested by jsc#SLE-10545, jsc#SLE-10902, jsc#SLE-10903,
  jsc#ECO-817 and jsc#ECO-818. This commit adds the additional
  monitoring modules for the LI and VLI images for SLE12-SP3
  and onward.
* Fri Jun 19 2020 ms@suse.de
- Added VLI blacklist config for SLE12 images
  Black listed ioatdma and skx_edac. This Fixes #225
* Wed Jun 17 2020 ms@suse.de
- Reference commit for SUSE maintenance
  This submission creates a reference to jsc#sle-11453
  and jsc#sle-11454 and covers changes related to the
  HLI (Hana Large Instance) project
* Fri Jun  5 2020 rjschwei@suse.com
- Update the motd to reflect the new link for the SUSE forums
* Thu May 28 2020 ms@suse.de
- Fixed schedule type
* Thu May 28 2020 ms@suse.de
- added mirror tag for production
  implement production scheduler on mirror host
* Mon May 25 2020 ms@suse.de
- Added prometheus monitoring modules
  As requested by jsc#SLE-10545, jsc#SLE-10902, jsc#SLE-10903,
  jsc#ECO-817 and jsc#ECO-818. This commit adds the additional
  monitoring modules for the LI and VLI images for SLE15-SP2.
  As soon as the modules are available for older versions/SPs
  we can add them there too
* Wed May  6 2020 ms@suse.de
- Bump version: 1.2.5 → 1.2.6
* Tue May  5 2020 ms@suse.de
- Added obs service refresh back
  On change of the image descriptions we want a service refresh
* Tue May  5 2020 ms@suse.de
- Added devel package auto submission
  On master and with tag set the package gets auto submitted
  which also triggers the rebuild of the devel images as a
  consequence
* Wed Apr 29 2020 ms@suse.de
- Fixed yaml with help from ci-lint
* Wed Apr 29 2020 ms@suse.de
- follow up fix for only setup
* Wed Apr 29 2020 ms@suse.de
- Fixed gitlab yaml setup
  Use of only section was invalid
* Wed Apr 29 2020 ms@suse.de
- Run mirror_testing_images variable dependant
  Run schedule only on SCHEDULE_TYPE set to mirror
* Wed Apr 29 2020 ms@suse.de
- Bump version: 1.2.4 → 1.2.5
* Fri Apr 24 2020 ms@suse.de
- Changed hop host for testing images upload
* Thu Apr 23 2020 ms@suse.de
- Update High value for kdump in VLI images
  Assume up to 16luns per machine and 224M High from kdumptool
  calibration. This results in 232M which we set for the
  very large instances as default now
* Thu Apr 23 2020 ms@suse.de
- Fixed High value calculation in kdump setup
  The High value gets calculated to match the requirements
  of the systems used at Microsoft. The result of the testing
  leads to the empiric formular dump-high * max(1, mem-TB) + LUN/2
  We know that this is not matching the various recommendations
  out on the web but this was reported to be working on the
  high mem systems used at Microsoft. We rate functionality
  over recommendations. This Fixes #203
* Tue Apr 21 2020 ms@suse.de
- Exclude jobs from schedules
  only the mirror of azure testing images is on schedule
* Tue Apr 21 2020 ms@suse.de
- Fixed gitlab yaml file
  Missing stage setup
* Tue Apr 21 2020 ms@suse.de
- Added mirror of Azure testing images
  Adds a gitlab schedule to mirror new testing images at 1am UTC(Berlin)
* Mon Apr 20 2020 ms@suse.de
- Added rsyslog to sle15 images
  There was no syslog package in the sle15 image installed.
  This lead to all kernel messages to be displayed on the
  console. It became an issue with all the alua warning
  messages that floods the console. This Fixes #202
* Mon Apr 20 2020 ms@suse.de
- Added system-group-wheel for sle15
  In SLE15 the install of the wheel group is no longer part
  of the standard installation. This commit adds the explicit
  install of the wheel group in all sle15 image descriptions
  This Fixes #214
* Thu Apr 16 2020 jesus.bv@suse.com
- Add requested packages to SLES 12 SP4
- numad
- libyui-qt-pkg7
  This Fixes #208
* Thu Apr 16 2020 ms@suse.de
- Set NamePolicy to path for VLI images
* Thu Apr 16 2020 jesus.bv@suse.com
- Blacklist modules to avoid emergency mode
  Modules blacklisted:
- ioatdma
- skx_edac
  This Fixes #210
* Fri Apr  3 2020 ms@suse.de
- Add obs artificats
  This pipeline job creates the static image files as they
  would be needed in the obs system if a source service
  is not allowed. This is usally the case for production
  submissions. Thus the data on the artificats link in
  gitlab now offers this data and can just be used to
  drive these type of submissions
* Tue Mar 24 2020 ms@suse.de
- Set link naming policy instead of rule rewrite
  Instead of rewriting all network interface names in a udev
  rule set the mac based network link policy in systemd
  This Fixes #167
* Mon Mar 23 2020 jesus.bv@suse.com
- Add nicer way to select network naming policies
  This Fixes #167
* Mon Mar 23 2020 ms@suse.de
- Added IBM java 1.8 to sle15 VLI image descriptions
  Added missing java-1_8_0-ibm package. This Fixes #193
* Fri Mar  6 2020 ms@suse.de
- Activate service update for master only
* Thu Mar  5 2020 ms@suse.de
- Added obs github service integration
  Changes in the image descriptions hosted on github will
  not automatically update the service in obs. This commit
  adds a pipeline to run the service update from a hop
  host that allows for only the service refresh command
  through ssh
* Thu Feb 20 2020 aosthof@suse.de
- Include salt formula packages etc. in SLES for SAP images
- Requested in jsc#11453 (Deployment of HANA Scale-up Performance Optimized Scenario from Salt (SUMA 4.0)
- Requested in jsc#11454 (Automate setup of DRBD NFS-Share in SALT and Terraform)
* Mon Feb  3 2020 ms@suse.de
- Set OBS-ExclusiveArch in all image descriptions
  Images for the Azure LI/VLI target are exclusive to the
  x86_64 architecture. This should be expressed in the image
  such that the OBS team knows it and no extra resources
  are wasted by building for other architectures
* Wed Jan  8 2020 ms@suse.de
- Fixed unresolvable in the SLE15 SP2 descriptions
  YaST complains about nothing provides libzypp.so... needed by
  libyui-ncurses-pkg9. the YaST team has fixed the naming issue
  such that this should be resolved once and for all by requesting
  libyui-ncurses-pkg without the number
* Tue Dec 10 2019 ms@suse.de
- Added SLE12 SP5 LI/VLI image descriptions
* Mon Dec  9 2019 ms@suse.de
- Added SLE15 GA image description
* Mon Nov 18 2019 ms@suse.de
- Bump version: 1.2.3 → 1.2.4
* Mon Nov 18 2019 ms@suse.de
- Reference commit for SUSE maintenance
  This submission creates a reference to bsc#1157041
* Mon Nov 18 2019 ms@suse.de
- Reference commit for SUSE maintenance
  This submission creates a reference to bsc#1157040
* Mon Nov 18 2019 ms@suse.de
- Bump version: 1.2.2 → 1.2.3
* Wed Nov  6 2019 jesus.bv@suse.com
- Right name for vli sp2 folder
* Wed Nov  6 2019 jesus.bv@suse.com
- Add folder for SLES15 SP2 VLI images
* Mon Nov  4 2019 ms@suse.de
- Fixed VLI package list for sle15
  cpp48 does not exist on sle15, instead the cpp package
  by its name provides is used. On sle15 this resolved to
  cpp7. This is related to Issue #186
* Mon Nov  4 2019 ms@suse.de
- Bump version: 1.2.1 → 1.2.2
* Sat Nov  2 2019 ms@suse.de
- Added Microsoft requested packages to VLI images
  This Fixes #186
* Wed Oct 30 2019 ms@suse.de
- Add retry loop to setup sbd device
  There is no deterministic way to know when the iSCSI device
  is ready to be processed by sbd. Thus the calls to setup the
  sbd device has been placed into a retry loop that runs max
  3 times with a 2sec wait period in between. This Fixes #188
* Fri Oct 25 2019 jesus.bv@suse.com
- Add directory for SLES15-SP2
* Wed Oct 23 2019 jesus.bv@suse.com
- Saptune setup
  As pointed before, saptune supersedes sapconf.
  This is the right path to setup saptune.
  Update image descriptions not to install sapconf.
  This Fixes #185
* Wed Oct 16 2019 ms@suse.de
- Update LI image versions
  For the refresh of the images in the SUSE namespace the version
  number has been increased
* Mon Oct 14 2019 ms@suse.de
- Bump version: 1.2.0 → 1.2.1
* Mon Oct 14 2019 jesus.bv@suse.com
- Right sequence saptune
  One of the issues is that `saptune` is a different tool that supersedes
  `sapconf`. Then the `saptune daemon restart` command will always
  overwrite the profile with `saptune`. Two different tools that can't be
  mixed. Only one should be used.
  In case of SLES (not SLES for SAP), the sequence should be
  For SLES 12
  ```
  tuned-adm profile sap-hana
  systemctl enable --now sapconf.service
  ```
  and for SLES15
  ```
  tuned-adm profile sapconf
  systemctl enable --now sapconf.service
  ```
  For SLES for SAP, the sequence is the same for 12 and 15:
  ```
  saptune daemon start
  saptune solution apply HANA
  ```
  This Fixes #172
* Thu Oct 10 2019 ms@suse.de
- Bump version: 1.1.39 → 1.2.0
* Thu Oct 10 2019 ms@suse.de
- Change the setup of the login shell
  The login shell was setup based on assumption regarding other
  user attributes set. This way caused some negative side effects
  which lets us change the behavior. This patch does the following
  * Adds a new attribute named: loginshell
  * If loginshell is present the value for loginshell will be used,
    if not the default /sbin/nologin applies
  * All implicit assumptions for setting up the login shell
    got deleted
    This Fixes #178
* Wed Oct  9 2019 jesus.bv@suse.com
- sbd device to wait for udev to finish
  This Fixes #179
* Fri Sep 20 2019 ms@suse.de
- Bump version: 1.1.38 → 1.1.39
* Wed Sep 18 2019 ms@suse.de
- Consolidate all image descriptions in git
  Instead of maintaining image descriptions in obs we want to
  maintain them in git. With this change only a service and
  multibuild configuration applies in obs but the data to
  build the image will live in git. This allows for real
  development and review regarding changes to the kiwi image
  descriptions.
* Wed Sep 18 2019 ms@suse.de
- Restart iscsi subsystem after device discovery
  Only after restart of the iscsi subsystem the device nodes
  from a previous device discovery gets created properly.
  This Fixes #170
* Tue Sep 17 2019 ms@suse.de
- Bump version: 1.1.37 → 1.1.38
* Tue Sep 17 2019 ms@suse.de
- Added more logging to the process
  Add a log file /var/log/azure-li-services.log which adds
  logging information from the service process. Usually error
  log information is present on the systemd level but for
  checking the process, it's calls and potential further information
  it's also useful to have a processing log file. The log file
  will be created on the host and gets also copied to the config
  lun in the same way as the systemd workload log
* Thu Sep 12 2019 ms@suse.de
- Bump version: 1.1.36 → 1.1.37
* Wed Sep 11 2019 ms@suse.de
- Delete ineffective startup.nsh code
  startup.nsh is read by the firmware in an early boot phase.
  It doesn't make sense to write that file as part of the boot
  services because it's too late in the process. startup.nsh
  if required needs to be provided by the image itself
* Wed Aug 28 2019 ms@suse.de
- Extend storage service dependencies
  The storage service can be used for remote storage like NFS
  storage to be attached to the machine. This requires the network
  to be online. Having the network only configured is not enough
  it must also be online. Thus the storage service unit is extended
  to wait for the network-online.target
* Tue Aug 27 2019 ms@suse.de
- Bump version: 1.1.35 → 1.1.36
* Mon Aug 26 2019 ms@suse.de
- Fixed network setup for bonding on vlan
  vlan network definitions that uses bonding etherdevices
  were missing a switch to correctly assign the ip configuration
  This Fixes #164
* Wed Jun 19 2019 ms@suse.de
- Bump version: 1.1.34 → 1.1.35
* Wed Jun 19 2019 ms@suse.de
- Apply saptune startup sequence suggested by $MS
  Implementing startup sequence as suggested in SAP Note 1275776.
  This Fixes #149
* Wed Jun 19 2019 ms@suse.de
- Log command calls on the console
  Implements a simple logging facility for the Command classes
  and write the commands called to the console. This will lead
  to more detailed information about the command calls in the
  systemd status information
* Wed Jun 19 2019 ms@suse.de
- Load yaml in safe mode
  The default yaml loader is unsafe, thus we should switch
  to the safe_load method. For details see: https://msg.pyyaml.org/load
* Wed Jun 19 2019 ms@suse.de
- Bump version: 1.1.33 → 1.1.34
* Tue Jun 18 2019 ms@suse.de
- Start saptune daemon after applying profile
  For some reason the saptune daemon needs to restart if a
  profile has been set through the tuned-adm profile command.
  This Fixes #149
* Tue Jun 18 2019 ms@suse.de
- Revert fix for service order of saptune daemon
  It has turned out that the simple change in order did
  not solve the problem. In fact the daemon needs to be
  restarted on profile setup
* Tue Jun 18 2019 jesus.bv@suse.com
- Allow ssh access with shell
  Allow access through ssh without shadow hash and
  with shell.
  Fixes #151
* Wed Jun 12 2019 ms@suse.de
- Bump version: 1.1.32 → 1.1.33
* Wed Jun 12 2019 ms@suse.de
- Fix service order on startup of saptune daemon
  The tuned profile must be applied prior to the start of
  the saptune daemon. This Fixes #149
* Mon Jun  3 2019 ms@suse.de
- Bump version: 1.1.31 → 1.1.32
* Fri May 31 2019 ms@suse.de
- Fixed travis badge link
* Fri May 31 2019 ms@suse.de
- Mount LUN in sync mode
  Per request from Microsoft the location that holds the
  config file and is also used for the status flag and
  log should be mounted with the sync option.
  This Fixes #144
* Fri May 31 2019 ms@suse.de
- Activate SAP Hana profile via tuned-adm
  Check for the presence of the sap-hana profile and switch
  to sapconf if not found. Activate the selected profile via
  the tuned-adm control command. This Fixes #142
* Tue May  7 2019 ms@suse.de
- Bump version: 1.1.30 → 1.1.31
* Tue May  7 2019 ms@suse.de
- Reference commit for SUSE maintenance
  This submission creates a reference to bsc#1133162 which
  got fixed in Issue #138
* Tue May  7 2019 ms@suse.de
- Bump version: 1.1.29 → 1.1.30
* Fri May  3 2019 ms@suse.de
- Umount LUN only on cleanup
  If one service(A) needs the LUN and another service(B) that needs
  the LUN too runs in parallel a potential race condition exists
  in a way the service A could have umounted the LUN exactly at
  a time service B accesses it. Thus this patch changes the
  services such that only the last service, the cleanup service
  umounts the LUN. This Fixes #137
* Fri Apr 26 2019 jesus.bv@suse.com
- Load softdog module when STONITH is set up
  It loads the module and make the load boot persistant
  This Fixes #138
* Thu Apr 11 2019 ms@suse.de
- Bump version: 1.1.28 → 1.1.29
* Wed Apr 10 2019 ms@suse.de
- Fixup system-setup service dependencies
  The setup of the stonith SBD device requires the network
  to be up beforehand because the target is an iSCSI endpoint.
  This Fixes #119
* Mon Apr  1 2019 ms@suse.de
- Bump version: 1.1.27 → 1.1.28
* Fri Mar 29 2019 ms@suse.de
- Create /etc/sysconfig/sbd configuration
  Write /etc/sysconfig/sbd which contains the disk device
  name used to initialize the SBD device
* Tue Mar 12 2019 ms@suse.de
- Add support for iSCSI SBD device setup
  In a new an optional stonith section the configuration for
  the iSCSI initiator and ip address can be setup. Once present
  the process to setup the iSCSI initiator as well as the
  device discovery is started. This Fixes bsc#1125373 and
  bsc#1125372 and Fixes #119
* Tue Mar  5 2019 ms@suse.de
- Bump version: 1.1.26 → 1.1.27
* Tue Mar  5 2019 ms@suse.de
- Tracker bug references
  This commit is a reference commit to track the update of
  the package for SLES. bsc#1127923 and bsc#1127924 references
  the implementations done with the Issues #121, #120 and #114
* Wed Feb 27 2019 ms@suse.de
- Bump version: 1.1.25 → 1.1.26
* Wed Feb 27 2019 ms@suse.de
- Fixed ifroute file name to match size limits
  Adapt ifroute- file name to match the new vlan interface naming
  and avoid exceeding the file name size limits
* Tue Feb 26 2019 ms@suse.de
- Bump version: 1.1.24 → 1.1.25
* Mon Feb 25 2019 ms@suse.de
- Bump version: 1.1.23 → 1.1.24
* Mon Feb 25 2019 ms@suse.de
- Followup fix for package installer
  Concatenation of packages still leads to multiple packages
  passed as one argument. This commit finally fixes the package
  list handling
* Mon Feb 25 2019 ms@suse.de
- Fixed network service vlan setup
  The vlan setup used the interface name in its ifcfg config
  file in the following format: ifcfg-<interface>.<vlan_id>
  However if the interface name is based on the MAC address
  that leads to a name which is longer than the fixed defined
  value from /usr/include/linux/if.h: #define IFNAMSIZ 16
  and will make the network setup to fail. Therefore this
  patch changes the config file for the vlan setup to follow
  the format: ifcfg-vlan<vlan_id> which avoids that size
  limit. This Fixes #115
* Mon Feb 25 2019 ms@suse.de
- Bump version: 1.1.22 → 1.1.23
* Mon Feb 25 2019 ms@suse.de
- Fix package installer
  zypper expects multiple packages as arguments, one argument
  per package, one argument with multiple packages is treated
  as one long package name and of course fails
* Mon Feb 25 2019 ms@suse.de
- Cleanup network service
  Delete unused elements from ifcfg configuration on suse systems
  * ONBOOT, obsolete if STARTMODE is used
  * VLAN, obsolete ETHERDEVICE gives the vlan type
  * DEVICE, obsolete and invalid use of self reference. suse
    only uses this in the context of PPP(oE) interfaces which
    are not of interest in the scope of Azure LI/VLI
* Mon Feb 25 2019 ms@suse.de
- Bump version: 1.1.21 → 1.1.22
* Sat Feb 23 2019 ms@suse.de
- Allow to specify install section per repo
  Update schema per last feedback. Allow to specify the
  install section per repository section. Restore former
  behavior for raw directory section, which installs all
  rpms from the given directories
* Mon Feb 18 2019 ms@suse.de
- Extend installer service
  Allow to configure multiple repositories and formats not only
  packages from a directory list. Specifically add packages to
  install in an install section. This Fixes #120
* Sun Feb 17 2019 ms@suse.de
- Added optional require_password_change attribute
  Allow to specify if the user password has to be changed on
  next logon. This Fixes #121
* Tue Feb 12 2019 ms@suse.de
- Bump version: 1.1.20 → 1.1.21
* Mon Feb 11 2019 ms@suse.de
- Added support for interface bonding
  Allow to setup bonding slaves on top of vlan interfaces
  or direct bonding structure. Because bonding slave interfaces
  comes with no ip/netmask setup the schema has to be changed
  to allow interface list elements without ip and subnet_mask
  fields which were required elements before.
  This Fixes #114
* Wed Jan  9 2019 ms@suse.de
- Bump version: 1.1.19 → 1.1.20
* Wed Jan  9 2019 ms@suse.de
- Submission to SUSE:SLE-15:Update
  This commit tracks the submission for fate#326575
  and bsc#1105612
* Wed Jan  9 2019 ms@suse.de
- Bump version: 1.1.18 → 1.1.19
* Wed Jan  9 2019 ms@suse.de
- Fixup createrepo requirement
  createrepo is no longer part of SLE15. The successor of this
  package is createrepo_c an implementation in C. Therefore
  the requires statement in the spec file should be changed to
  work with both distributions: SLE12 and SLE15.
* Tue Jan  8 2019 ms@suse.de
- Support MTU setup for standard and vlan interfaces
  Enhanced the config schema to allow the networking attributes
  mtu and vlan_mtu as optional arguments to configure the maximum
  transfer unit for the interface and/or its virtual type. In
  addition add a differentiator for the VeryLarge instance types
  in generation 3 and its successor. For Gen3 VeryLarge instance
  types the network setup was not yet defined because we haven't
  started to support this target. However the successor of the
  VeryLarge instance type is similar in the infrastructure and
  boot compared to the LargeInstance type and can be covered
  by the network service in the same way. This Fixes #105
  and Fixes bsc#1120522
* Mon Jan  7 2019 ms@suse.de
- Bump version: 1.1.17 → 1.1.18
* Mon Jan  7 2019 ms@suse.de
- Submission to SUSE:SLE-15:Update
  This commit tracks the submission for fate#326575
  and bsc#1103542
* Tue Dec 18 2018 ms@suse.de
- Bump version: 1.1.16 → 1.1.17
* Tue Dec 18 2018 ms@suse.de
- Update package build due to guidelines
* Mon Dec 17 2018 ms@suse.de
- Bump version: 1.1.15 → 1.1.16
* Mon Dec 17 2018 ms@suse.de
- Tracker bug reference
  Update of the package is tracked in bsc#1119702
* Tue Dec 11 2018 ms@suse.de
- Bump version: 1.1.14 → 1.1.15
* Mon Dec 10 2018 ms@suse.de
- Fixed group processing in setup_ssh_authorization
  The change in the schema to specify group names/id was not
  handled in the code processing the setup of the ssh
  authorization. As there was a group key before and after the
  change in the schema but with a different result and used
  only as parameters to a mocked grp.getgrnam() system call
  the unit tests did not uncover the issue. This Fixes #98
* Wed Nov 21 2018 ms@suse.de
- Bump version: 1.1.13 → 1.1.14
* Tue Nov 20 2018 ms@suse.de
- Write workload log file
  In case of a deployment error, a log file in addition to the
  status flag files is written which contains the systemd
  service log information from all services ran so far.
  The log file is written to the storage location from which
  the yaml config file was read from. It is expected that
  this location is writable and offers enough space to store
  the logfile. In case of an error writing the log we will
  treat this as "bad luck" and continue with the cleanup.
  This Fixes #96
* Fri Nov 16 2018 ms@suse.de
- Cleanup code to make flake8 happy
  The new version of flake8 is more strict on code checking and
  complained at several places. This commit fixes the code smells
  such that flake8 is happy again
* Fri Nov 16 2018 ms@suse.de
- Added workload status flag file
  At the time of the cleanup service a file named:
  workload_success_is_true or workload_success_is_false
  will be written on the storage location the config file
  was read from. At the time this file appears it's also
  safe to release the config file storage location from
  the system. This Fixes #93
* Fri Sep 21 2018 ms@suse.de
- Bump version: 1.1.12 → 1.1.13
* Fri Sep 21 2018 ms@suse.de
- Refactor group schema
  The description of a user group must be connected to a
  name, whereas the group id is an optional information.
  This should be also reflected in the schema
* Wed Sep 19 2018 ms@suse.de
- Allow optional group_id in user data
  This Fixes #90
* Mon Sep 17 2018 ms@suse.de
- Bump version: 1.1.11 → 1.1.12
* Mon Sep 17 2018 ms@suse.de
- Bump version: 1.1.10 → 1.1.11
* Mon Sep 17 2018 ms@suse.de
- Replace pre/post section with descriptive comment
* Mon Sep 17 2018 rjschwei@suse.com
- Fix typos in spec file comment
* Fri Sep 14 2018 ms@suse.de
- Fix inconsistent cleanup service
  The introduction of the pre/post scripts in the package which
  runs systemd macros to delete the services causes a core dump
  on zypper and prevents the cleanup service from actually
  uninstalling the package. Thus I suggest to delete those
  pre/post actions from the package and leave this in the hand
  of the cleanup service using the reset-failed command from
  systemd after uninstall of the package has been performed.
  This references Issue #88
* Fri Sep 14 2018 ms@suse.de
- Bump version: 1.1.9 → 1.1.10
* Thu Sep 13 2018 rjschwei@suse.com
- Properly handle service stop/restart on package update or removal
* Wed Sep 12 2018 ms@suse.de
- Bump version: 1.1.8 → 1.1.9
* Tue Sep 11 2018 ms@suse.de
- Allow to activate/deactivate the crash dump setup
  The crash dump setup deserves its own section containing
  the optional high/low values as well as a new switch to
  control the activation of the setup process.
  This Fixes #78
* Thu Aug 23 2018 ms@suse.de
- Bump version: 1.1.7 → 1.1.8
* Thu Aug 23 2018 ms@suse.de
- Follow up fix for mount location checkup
  Provides a umount_config_source method in the Defaults
  space to allow to perform an umount which succeeds even
  if the mountpoint is busy. The umount is performed as
  Lazy unmount and detaches the filesystem from the file
  hierarchy now, and clean up all references to this
  filesystem as soon as it is not busy anymore.
  This Fixes #76
* Tue Aug 21 2018 ms@suse.de
- Bump version: 1.1.6 → 1.1.7
* Tue Aug 21 2018 ms@suse.de
- Check if mount location is already mounted
  Call the mountpoint command in mount_config_source prior to the
  actual mount and perform the mount process only if the location
  is not already an active mountpoint. This Fixes #74
* Fri Aug 17 2018 ms@suse.de
- Bump version: 1.1.5 → 1.1.6
* Thu Aug 16 2018 ms@suse.de
- Accumulate errors in user service
  Instead of exiting at the first raise condition continue
  setting up other users and raise with the collection of
  potential errors. Fixes #71
* Thu Aug 16 2018 ms@suse.de
- Accumulate errors in system_setup service
  Instead of exiting at the first raise condition continue
  setting up other system components and raise with the
  collection of potential errors. Issue #71
* Thu Aug 16 2018 ms@suse.de
- Accumulate errors in storage service
  Instead of exiting at the first raise condition continue
  setting up other storage mounts and raise with the
  collection of potential errors. Issue #71
* Thu Aug 16 2018 ms@suse.de
- Accumulate errors in network service
  Instead of exiting at the first raise condition continue
  setting up other network interfaces and raise with the
  collection of potential errors. Issue #71
* Thu Aug 16 2018 ms@suse.de
- Accumulate errors in machine_constraints service
  Instead of exiting at the first raise condition continue
  checking other machine constraints and raise with the
  collection of potential errors. Issue #71
* Thu Aug 16 2018 ms@suse.de
- Don't raise on missing vlan id
  The vlan setup is an add-on setup if a vlan id is given.
  If it's not given the other network components are still
  valid and this does not justify create_vlan_config to raise
  an exception but just skip the vlan setup
* Thu Aug 16 2018 ms@suse.de
- Fixed access of unbound variable
  For the copy of the ssh private key the location providing the
  key is mounted first and umounted when done. However the location
  information from the mount is unknown in the scope of the final
  block performing the umount. This Fixes #70
* Wed Aug 15 2018 ms@suse.de
- Fixup system inconsistency on module loading
  Make sure that no services module code is loaded from disk after
  the cleanup service has uninstalled the azure-li-services package.
  All follow up code after the uninstall must be kept in memory.
  This Fixes #68
* Tue Aug 14 2018 ms@suse.de
- Submission to SUSE:SLE-12-SP3:Update:PubClouds
  This commit tracks the submission for fate#326575
  and bsc#1103542
* Thu Aug  2 2018 ms@suse.de
- Bump version: 1.1.4 → 1.1.5
* Fri Jul 27 2018 ms@suse.de
- Allow reboot of the system via kexec
  This patch set is two fold:
  First it adds a reboot flag to the status report
  and extends the cleanup service to allow for reboot of
  the system via kexec if all services were successful
  and at least one requests for reboot of the system in
  its result report.
  Second it extends the system setup service for the
  crash kernel memory setup in a way that the high
  value if not set via the config file is calculated
  based on the amount of main memory. If the preconfigured
  values have changed the system_setup service also
  activates the reboot flag in its status report
  This Fixes #64
* Thu Jul 26 2018 ms@suse.de
- Fixup saptune startup sequence
  Regarding a discussion with Peter Schinagl the sequence
  to start the saptune daemon was wrong and is fixed with
  this commit. Fixes #65
* Thu Jul 19 2018 ms@suse.de
- Bump version: 1.1.3 → 1.1.4
* Wed Jul 18 2018 ms@suse.de
- Update schema semantic to specify ssh private key
  The former ssh private key specification was based on
  a custom file name and a target name for the key. The
  given file name was copied and renamed as specified.
  However the renaming seems superfluous and can be
  avoided by specifying just the file name and copying
  as such to the right place.
* Tue Jul 17 2018 ms@suse.de
- Refactor reading of ssh private key
  Instead of specifying a base64 encoded private ssh key
  string as part of the key element in the config file,
  we now just read a file path reference which is expected
  to exist on the storage location from where the config
  file was read. The referenced file is copied as the
  ssh private key of the configured user. This sets the
  config file free from any secret data and Fixes #58
* Tue Jul 17 2018 ms@suse.de
- Fixup runtime order of report service
  Next try to make sure the report service runs before
  any getty@.service is called. The getty@.service is
  configured to run after systemd-user-sessions.service
  Thus we should be safe if the reporting service runs
  before systemd-user-sessions.service
* Tue Jul 10 2018 ms@suse.de
- Added reboot intervention on Very Large Instances
  For Very Large Instance platforms the reboot may not happen
  without operator intervention. On EFI systems this can be
  done by an efi call script: startup.nsh. This method was
  preferred over setting a BIOS boot option through the Bios
  menu by the Microsoft ops team. This Fixes #46
* Mon Jul  9 2018 ms@suse.de
- Seems like latest tox version is broken
  Pin the version to 2.9.1 for the moment
* Mon Jul  9 2018 ms@suse.de
- Setup start of saptune daemon and tuned service
  The start of the service requires the sap-hana profile
  to be installed on the system. The hana profile as of
  today is delivered by a custom package from $MS, installed
  via the azure-li-install service. Thus the system_setup
  service now runs after the install service.
  This Fixes #52
* Sun Jul  8 2018 ms@suse.de
- Call kdump calibrate only when needed
* Fri Jul  6 2018 ms@suse.de
- Added kernel crash dump setup
  Allows the setup of custom kernel crash dump values from the
  yaml config file. If not specified the kdumptool calibration
  results will be used to setup the high and low memory range to
  store crash dumps. Please also note that the image comes with
  a pre-configured crashdump setup in case the kernel crashes
  before this system_setup service has done its job.
  This Fixes #50
* Thu Jul  5 2018 ms@suse.de
- Added samepage and energy performance setup
  Extend the system_setup service with the setup of the
  kernel samepage handling and energy performance selection.
  This Fixes #54 and Fixes #53
* Thu Jun 28 2018 ms@suse.de
- Bump version: 1.1.2 → 1.1.3
* Wed Jun 27 2018 ms@suse.de
- Fix service order for storage unit
  The storage service has to run after the network target
  has been reached. This Fixes #49
* Thu Jun 21 2018 ms@suse.de
- Allow import of private key
  Add an additional optional sub section named ssh-private-key
  into the credentials section. The section allows for a name
  which is the base filename of an ssh private key and the key
  value encoded as base64 string. This Fixes #42
* Thu Jun 21 2018 ms@suse.de
- Bump version: 1.1.1 → 1.1.2
* Thu Jun 21 2018 ms@suse.de
- Added system_setup to report service
* Thu Jun 21 2018 ms@suse.de
- Bump version: 1.1.0 → 1.1.1
* Thu Jun 21 2018 ms@suse.de
- Make hostname an optional setup
* Wed Jun 20 2018 ms@suse.de
- Added system_setup service
  Along with the service the setup of the hostname has
  been implemented. This Fixes #40
* Tue Jun 19 2018 ms@suse.de
- Fixup success state for optional services
  This Fixes #43
* Tue Jun 19 2018 ms@suse.de
- Make sure report service starts before getty
  This Fixes #38
* Tue Jun 19 2018 ms@suse.de
- Improve error handling on mount_config_source
  Provide more detail on the used sequence of mount
  calls and their errors
* Tue Jun 19 2018 ms@suse.de
- Fixup ssh files ownership in user service
  ssh files must be owned by the user they belong to. In addition
  the home path of the root user is not located in the standard
  home directory of users and needs an extra handling. This
  Fixes #37
* Mon Jun 18 2018 ms@suse.de
- networking is required
* Mon Jun 18 2018 ms@suse.de
- Update schema constraints per review
* Thu Jun 14 2018 ms@suse.de
- Added DVD fallback mounting sequence
  Primarily we mount a LUN by label, but if that failed a
  fallback mount from /dev/dvd kicks in. Only if that fails
  the overall mount attempt has failed. This Fixes #13
* Thu Jun 14 2018 ms@suse.de
- Added schema validation for config file
  This Fixes #31
* Wed Jun 13 2018 ms@suse.de
- Bump version: 1.0.0 → 1.1.0
* Wed Jun 13 2018 ms@suse.de
- Make sure mount point path gets created
* Tue Jun 12 2018 ms@suse.de
- Added storage to report service
* Tue Jun 12 2018 ms@suse.de
- Added machine_constraints to report service
* Tue Jun 12 2018 ms@suse.de
- Added free space validation
* Tue Jun 12 2018 ms@suse.de
- Added storage service
  Updates fstab with new entries from the optional storage
  section and activates the new mount locations.
  This Fixes #10
* Tue Jun 12 2018 ms@suse.de
- Separate issue report from cleanup service
  Put the report code into its own service and handle
  the dependency chain from within the systemd unit
  files. report runs after all services which creates a
  status report and cleanup runs after report
* Tue Jun 12 2018 ms@suse.de
- Simplify dict access
* Tue Jun 12 2018 ms@suse.de
- Use binary multiples of bytes (powers of two)
  Storage sizes as we work with here are always byte values
* Mon Jun 11 2018 ms@suse.de
- Added machine constraint checker service
  Validate min_cores and min_memory constraints on the
  machine when booting. This Fixes #30
* Mon Jun 11 2018 ms@suse.de
- Added overall state check for cleanup service
  Added check for success state from all services and update
  the /etc/issue file if one or more services have a failed
  state. This completes and Fixes #19
* Mon Jun 11 2018 ms@suse.de
- Bump version: 0.4.1 → 1.0.0
* Mon Jun 11 2018 ms@suse.de
- Handle missing credentials section as error
  If no credentials section is specified in the config file
  this should be reported as an error. That's because in the
  image no user login will be allowed and therefore the
  credentials setup from the config file is the only door
  opener and mandatory for any subsequent work with the
  system. This Fixes #29
* Fri Jun  8 2018 ms@suse.de
- Fix unit test for install unit
* Fri Jun  8 2018 ms@suse.de
- Better name for the user method
  As create_user actually creates or modifies if the
  user already exists, the name should reflect this
* Fri Jun  8 2018 ms@suse.de
- Move status report directory to /var/lib
* Fri Jun  8 2018 ms@suse.de
- Fixup user service for handling existing users
  If the user setup in the config file already exists on the
  system, the user service failed to add that user as it
  should rather modify it. This Fixes #25
* Fri Jun  8 2018 ms@suse.de
- Handle missing packages source as error
  The install service did not handle an empty list of packages
  sources as an error and just proceeded without installing
  packages. However in the scope of the large instance setup
  it is expected that there are packages to install and if
  not this is an error condition. This Fixes #26
* Thu Jun  7 2018 ms@suse.de
- Fixup ssh directory and setup file permissions
* Thu Jun  7 2018 ms@suse.de
- Let services report result status
  In preperation to operate on an overall success or failed
  state depending on the result of the individual services,
  each service should have an easy way to report its result
  state. The StatusReport class implements this in a way
  that each service reports its state in a yaml file written
  to the directory provided by get_status_report_directory().
  As services are called by systemd and will run in parallel,
  one file per service name is created to avoid potential
  I/O conflicts on write. Issue #19
* Wed Jun  6 2018 ms@suse.de
- Added cleanup service
  After all services got called the cleanup service kicks in
  and uninstalls the azure-li-services package. This Fixes #12
* Wed Jun  6 2018 ms@suse.de
- Ensure /etc/suse_firstboot_config.yaml is at 0600
  This is related to Issue #12
* Mon Jun  4 2018 ms@suse.de
- Cleanup of config file format
  Per discussion this commit adds a revised version of the
  config file format to become active. Basic changes are:
  * networking moved on toplevel
  * blade section gets deleted, sku moved to toplevel
  * storage section was reworked
  * new section machine_constraints contains min_cores and
    min_memory values the machine has to provide
* Fri Jun  1 2018 ms@suse.de
- Bump version: 0.4.0 → 0.4.1
* Fri Jun  1 2018 ms@suse.de
- Fixed rsync command invocation
  For pattern matching a shell environment is required
* Fri Jun  1 2018 ms@suse.de
- Fixed call service unit
  Fixed wrong condition trigger file reference
* Fri Jun  1 2018 ms@suse.de
- Bump version: 0.3.0 → 0.4.0
* Wed May 30 2018 ms@suse.de
- Added package install service
  Allow to install packages from local repository
  This Fixes #7
* Wed May 30 2018 ms@suse.de
- Bump version: 0.2.0 → 0.3.0
* Tue May 29 2018 ms@suse.de
- Bump version: 0.1.0 → 0.2.0
* Thu May 24 2018 rjschwei@suse.com
- Fix service ordering for network setup
  + The network setup needs to be written before any of the netwroking
    services are started by systemd, or we have to explicitly restart the
    networking. This order is only guaranteed with the network-pre.target
* Fri May 18 2018 ms@suse.de
- Fixup sudo authorization
  Setup of sudoers and admin group must be done only once
* Fri May 18 2018 ms@suse.de
- Allow for multiple user setup
  In addition more elements of the user can be specified
  such as user id, group and home_dir
* Fri May 18 2018 ms@suse.de
- Be more clear on call argument
* Fri May 18 2018 ms@suse.de
- Update runtime config key description
* Fri May 18 2018 ms@suse.de
- Added script call service
* Fri May 18 2018 ms@suse.de
- Added User service
  Creates the configured user and its access setup for ssh
  and sudo services in the scope of an Azure Li/Vli instance
  This Fixes #6
* Thu May 17 2018 ms@suse.de
- Bump version: 0.0.6 → 0.1.0
* Wed May 16 2018 ms@suse.de
- Refactor misleading class names
  Using Li in names that covers implementation for Li and VLi may
  lead to confusion in the future when we need to differentiate
  between the two, the namespace should be free for that purpose
* Wed May 16 2018 ms@suse.de
- Time never stops
* Wed May 16 2018 ms@suse.de
- Refactor network service
  Change on the design to allow for running different code
  paths depending on if the instance is a LargeInstance or
  a VeryLargeInstance. Apply the instance distinction with
  the network service
* Tue May 15 2018 ms@suse.de
- Added azure-li-network service
  Work through the networking section of the Azure Li/Vli config
  file and setup the network configuration for this instance
  type. This Fixes #4
* Wed May  9 2018 ms@suse.de
- Bump version: 0.0.5 → 0.0.6
* Wed May  9 2018 ms@suse.de
- Fixed system unit
  systemd requires absolute path to binary
* Wed May  9 2018 ms@suse.de
- Bump version: 0.0.4 → 0.0.5
* Wed May  9 2018 ms@suse.de
- Fixed spec file
  python3-setuptools is required
* Tue May  8 2018 ms@suse.de
- Fixed spec file template
  Update to common source tarball name
* Tue May  8 2018 ms@suse.de
- Bump version: 0.0.3 → 0.0.4
* Tue May  8 2018 ms@suse.de
- Update spec file
  Create common style source tarball
* Tue May  8 2018 ms@suse.de
- Bump version: 0.0.2 → 0.0.3
* Tue May  8 2018 ms@suse.de
- Build changelog from git history
* Tue May  8 2018 ms@suse.de
- Bump version: 0.0.1 → 0.0.2
* Tue May  8 2018 ms@suse.de
- Fixed bumpversion config file
  Wrong path to version file
* Mon May  7 2018 ms@suse.de
- Update per agreement on config file name
* Fri May  4 2018 ms@suse.de
- Implement config lookup service
  The implementation is based on mounting a device by label
  and lookup of a pre defined file name on the root of that
  mount point. This Fixes #1 and This Fixes #2
* Fri May  4 2018 ms@suse.de
- Added Command and Path class
  Classes for command invocation and lookup
* Wed Apr 25 2018 ms@suse.de
- Fixed spec file source directory name
* Wed Apr 25 2018 ms@suse.de
- Fixed spec file source name
* Wed Apr 25 2018 ms@suse.de
- Added config_lookup service
  Implementation is still incomplete as we don't know
  how Azure presents the file to the instance.
* Mon Apr 23 2018 ms@suse.de
- Added RuntimeConfig class
  Implements reading of Azure LI/VLI runtime config file
* Mon Apr 23 2018 ms@suse.de
- Add package template
